==> Gridcoin-Research-5.3.3.0.tar.gz: Gridcoin-Research-5.3.3.0/src/qt/locale/bitcoin_cy.ts <==
<TS language="cy" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Double-click to edit address or label</source>
        <translation>Clicio dwywaith i olygu cyfeiriad neu label</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Creu cyfeiriad newydd</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Newydd</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copio'r cyfeiriad sydd wedi'i ddewis i'r clipfwrdd system</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copïo</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Dileu</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(heb label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Teipiwch gyfrinymadrodd</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Cyfrinymadrodd newydd</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ailadroddwch gyfrinymadrodd newydd</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Amgryptio'r waled</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Mae angen i'r gweithred hon ddefnyddio'ch cyfrinymadrodd er mwyn datgloi'r waled.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Datgloi'r waled</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Mae angen i'r gweithred hon ddefnyddio'ch cyfrinymadrodd er mwyn dadgryptio'r waled.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dadgryptio'r waled</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Newid cyfrinymadrodd</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Teipiwch yr hen cyfrinymadrodd a chyfrinymadrodd newydd i mewn i'r waled.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Cadarnau amgryptiad y waled</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Waled wedi'i amgryptio</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Amgryptiad waled wedi methu</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Methodd amgryptiad y waled oherwydd gwall mewnol. Ni amgryptwyd eich waled.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Dydy'r cyfrinymadroddion a ddarparwyd ddim yn cyd-fynd â'u gilydd.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Methodd ddatgloi'r waled</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Methodd dadgryptiad y waled</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Trosolwg</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Dangos trosolwg cyffredinol y waled</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Pori hanes trafodion</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>A&amp;llanfa</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Gadael rhaglen</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsiynau</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Amgryptio'r waled...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Newid cyfrinymadrodd...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Newid y cyfrinymadrodd a ddefnyddiwyd ar gyfer amgryptio'r waled</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Waled</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Anfon</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Derbyn</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Dangos / Cuddio</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Ffeil</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Gosodiadau</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Cymorth</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Cyfamserol</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Dal i fyny</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Trafodiad a anfonwyd</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Trafodiad sy'n cyrraedd</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Mae'r waled &lt;b&gt;wedi'i amgryptio&lt;/b&gt; ac &lt;b&gt;ar glo&lt;/b&gt; ar hyn o bryd</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Maint</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(heb label)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Golygu'r cyfeiriad</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Cyfeiriad</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Cyfeiriad derbyn newydd</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Cyfeiriad anfon newydd</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Golygu'r cyfeiriad derbyn</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Golygu'r cyfeiriad anfon</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Mae'r cyfeiriad "%1" sydd newydd gael ei geisio gennych yn y llyfr cyfeiriad yn barod.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Methodd ddatgloi'r waled.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Methodd gynhyrchu allwedd newydd.</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsiynau</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Rhwydwaith</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ffenestr</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Dangos</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Ffurflen</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Gwybodaeth</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Agor</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Anfon arian</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Maint</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Anfon at pobl lluosog ar yr un pryd</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Cadarnhau'r gweithrediad anfon</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(heb label)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Maint</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Agor tan %1</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Neges</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Math</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Agor tan %1</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Heddiw</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Eleni</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Math</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>Gwall</translation>
    </message>
</context>
</TS>

==> Gridcoin-Research-5.4.9.0.tar.gz: Gridcoin-Research-5.4.9.0/src/qt/locale/bitcoin_cy.ts <==
<TS language="cy" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Creu cyfeiriad newydd</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Newydd</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copio'r cyfeiriad sydd wedi'i ddewis i'r clipfwrdd system</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copïo</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Dileu</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(heb label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Teipiwch gyfrinymadrodd</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Cyfrinymadrodd newydd</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ailadroddwch gyfrinymadrodd newydd</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Amgryptio'r waled</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Mae angen i'r gweithred hon ddefnyddio'ch cyfrinymadrodd er mwyn datgloi'r waled.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Datgloi'r waled</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Newid cyfrinymadrodd</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Teipiwch yr hen cyfrinymadrodd a chyfrinymadrodd newydd i mewn i'r waled.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Cadarnau amgryptiad y waled</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Waled wedi'i amgryptio</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Amgryptiad waled wedi methu</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Methodd amgryptiad y waled oherwydd gwall mewnol. Ni amgryptwyd eich waled.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Dydy'r cyfrinymadroddion a ddarparwyd ddim yn cyd-fynd â'u gilydd.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Methodd ddatgloi'r waled</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Waled</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Trosolwg</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Dangos trosolwg cyffredinol y waled</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Anfon</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Derbyn</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Pori hanes trafodion</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>A&amp;llanfa</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Gadael rhaglen</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsiynau</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Dangos / Cuddio</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Amgryptio'r waled...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Newid cyfrinymadrodd...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Newid y cyfrinymadrodd a ddefnyddiwyd ar gyfer amgryptio'r waled</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Ffeil</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Gosodiadau</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Cymorth</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Cyfamserol</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Dal i fyny</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Trafodiad a anfonwyd</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Trafodiad sy'n cyrraedd</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Mae'r waled &lt;b&gt;wedi'i amgryptio&lt;/b&gt; ac &lt;b&gt;ar glo&lt;/b&gt; ar hyn o bryd</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Maint</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(heb label)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Golygu'r cyfeiriad</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Cyfeiriad</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Cyfeiriad derbyn newydd</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Cyfeiriad anfon newydd</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Golygu'r cyfeiriad derbyn</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Golygu'r cyfeiriad anfon</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Mae'r cyfeiriad "%1" sydd newydd gael ei geisio gennych yn y llyfr cyfeiriad yn barod.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Methodd ddatgloi'r waled.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Methodd gynhyrchu allwedd newydd.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsiynau</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Rhwydwaith</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ffenestr</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Dangos</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Ffurflen</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Gwybodaeth</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Agor</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Anfon arian</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Maint</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Anfon at pobl lluosog ar yr un pryd</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Cadarnhau'r gweithrediad anfon</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(heb label)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Maint</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Neges:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Agor tan %1</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Neges</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Math</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Agor tan %1</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Heddiw</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Eleni</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Math</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>Gwall</translation>
    </message>
</context>
</TS>
